@@ -1,4 +1,4 @@
-// $Id: genres.h,v 1.4 2006/02/13 17:42:45 khlut Exp $
+// $Id: genres.h,v 1.5 2006/02/25 07:21:42 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -25,6 +25,9 @@
 #include <prmem.h>
 #include <prthread.h>
 #include <plevent.h>
+#if (NP_VERSION_MAJOR==0)&&(NP_VERSION_MINOR<14)
+#error "Version of the Mozilla development files is too old. Firefox 1.0 or Mozilla 1.7.5 or newer is necessary."
+#endif
 
 // Plugin functions for function table
 
