@@ -1,4 +1,4 @@
-// $Id: observer_thread.c,v 1.3 2006/02/13 17:42:46 khlut Exp $
+// $Id: observer_thread.c,v 1.4 2006/03/19 20:18:50 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -65,7 +65,7 @@ void PR_CALLBACK observer_thread( PD * pd )
 	i=strlen(buf);
         if(buf[--i]=='\n')  buf[i]=0;
 	if(!i)		continue;
-	while(pd->refcnt>30 && pd->status!=Cancelling) {PR_Sleep(100); Debug("wait main thread\n"); continue;}
+	while(pd->refcnt>30 && pd->status!=Cancelling) {PR_Sleep(100); Debug("%p wait main thread\n",pd); continue;}
 	while(pd->status!=Cancelling && !post_event_to_thread( pd->browser, strevent, pd, buf )) PR_Sleep(100);
     } 
     PR_Lock(pd->lock);
